==> openshift-model-config-6.3.0-sources.jar: io/fabric8/openshift/api/model/config/v1/RegistrySourcesFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface RegistrySourcesFluent<A extends RegistrySourcesFluent<A>> extends Fluent<A>{
  public A addToAllowedRegistries(Integer index,String item);
  public A setToAllowedRegistries(Integer index,String item);
  public A addToAllowedRegistries(java.lang.String... items);
  public A addAllToAllowedRegistries(Collection<String> items);
  public A removeFromAllowedRegistries(java.lang.String... items);
  public A removeAllFromAllowedRegistries(Collection<String> items);
  public List<String> getAllowedRegistries();
  public String getAllowedRegistry(Integer index);
  public String getFirstAllowedRegistry();
  public String getLastAllowedRegistry();
  public String getMatchingAllowedRegistry(Predicate<String> predicate);
  public Boolean hasMatchingAllowedRegistry(Predicate<String> predicate);
  public A withAllowedRegistries(List<String> allowedRegistries);
  public A withAllowedRegistries(java.lang.String... allowedRegistries);
  public Boolean hasAllowedRegistries();
  public A addToBlockedRegistries(Integer index,String item);
  public A setToBlockedRegistries(Integer index,String item);
  public A addToBlockedRegistries(java.lang.String... items);
  public A addAllToBlockedRegistries(Collection<String> items);
  public A removeFromBlockedRegistries(java.lang.String... items);
  public A removeAllFromBlockedRegistries(Collection<String> items);
  public List<String> getBlockedRegistries();
  public String getBlockedRegistry(Integer index);
  public String getFirstBlockedRegistry();
  public String getLastBlockedRegistry();
  public String getMatchingBlockedRegistry(Predicate<String> predicate);
  public Boolean hasMatchingBlockedRegistry(Predicate<String> predicate);
  public A withBlockedRegistries(List<String> blockedRegistries);
  public A withBlockedRegistries(java.lang.String... blockedRegistries);
  public Boolean hasBlockedRegistries();
  public A addToContainerRuntimeSearchRegistries(Integer index,String item);
  public A setToContainerRuntimeSearchRegistries(Integer index,String item);
  public A addToContainerRuntimeSearchRegistries(java.lang.String... items);
  public A addAllToContainerRuntimeSearchRegistries(Collection<String> items);
  public A removeFromContainerRuntimeSearchRegistries(java.lang.String... items);
  public A removeAllFromContainerRuntimeSearchRegistries(Collection<String> items);
  public List<String> getContainerRuntimeSearchRegistries();
  public String getContainerRuntimeSearchRegistry(Integer index);
  public String getFirstContainerRuntimeSearchRegistry();
  public String getLastContainerRuntimeSearchRegistry();
  public String getMatchingContainerRuntimeSearchRegistry(Predicate<String> predicate);
  public Boolean hasMatchingContainerRuntimeSearchRegistry(Predicate<String> predicate);
  public A withContainerRuntimeSearchRegistries(List<String> containerRuntimeSearchRegistries);
  public A withContainerRuntimeSearchRegistries(java.lang.String... containerRuntimeSearchRegistries);
  public Boolean hasContainerRuntimeSearchRegistries();
  public A addToInsecureRegistries(Integer index,String item);
  public A setToInsecureRegistries(Integer index,String item);
  public A addToInsecureRegistries(java.lang.String... items);
  public A addAllToInsecureRegistries(Collection<String> items);
  public A removeFromInsecureRegistries(java.lang.String... items);
  public A removeAllFromInsecureRegistries(Collection<String> items);
  public List<String> getInsecureRegistries();
  public String getInsecureRegistry(Integer index);
  public String getFirstInsecureRegistry();
  public String getLastInsecureRegistry();
  public String getMatchingInsecureRegistry(Predicate<String> predicate);
  public Boolean hasMatchingInsecureRegistry(Predicate<String> predicate);
  public A withInsecureRegistries(List<String> insecureRegistries);
  public A withInsecureRegistries(java.lang.String... insecureRegistries);
  public Boolean hasInsecureRegistries();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/RegistrySourcesFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RegistrySourcesFluent<A extends RegistrySourcesFluent<A>> extends Fluent<A>{
  public A addToAllowedRegistries(int index,String item);
  public A setToAllowedRegistries(int index,String item);
  public A addToAllowedRegistries(java.lang.String... items);
  public A addAllToAllowedRegistries(Collection<String> items);
  public A removeFromAllowedRegistries(java.lang.String... items);
  public A removeAllFromAllowedRegistries(Collection<String> items);
  public List<String> getAllowedRegistries();
  public String getAllowedRegistry(int index);
  public String getFirstAllowedRegistry();
  public String getLastAllowedRegistry();
  public String getMatchingAllowedRegistry(Predicate<String> predicate);
  public Boolean hasMatchingAllowedRegistry(Predicate<String> predicate);
  public A withAllowedRegistries(List<String> allowedRegistries);
  public A withAllowedRegistries(java.lang.String... allowedRegistries);
  public Boolean hasAllowedRegistries();
  public A addToBlockedRegistries(int index,String item);
  public A setToBlockedRegistries(int index,String item);
  public A addToBlockedRegistries(java.lang.String... items);
  public A addAllToBlockedRegistries(Collection<String> items);
  public A removeFromBlockedRegistries(java.lang.String... items);
  public A removeAllFromBlockedRegistries(Collection<String> items);
  public List<String> getBlockedRegistries();
  public String getBlockedRegistry(int index);
  public String getFirstBlockedRegistry();
  public String getLastBlockedRegistry();
  public String getMatchingBlockedRegistry(Predicate<String> predicate);
  public Boolean hasMatchingBlockedRegistry(Predicate<String> predicate);
  public A withBlockedRegistries(List<String> blockedRegistries);
  public A withBlockedRegistries(java.lang.String... blockedRegistries);
  public Boolean hasBlockedRegistries();
  public A addToContainerRuntimeSearchRegistries(int index,String item);
  public A setToContainerRuntimeSearchRegistries(int index,String item);
  public A addToContainerRuntimeSearchRegistries(java.lang.String... items);
  public A addAllToContainerRuntimeSearchRegistries(Collection<String> items);
  public A removeFromContainerRuntimeSearchRegistries(java.lang.String... items);
  public A removeAllFromContainerRuntimeSearchRegistries(Collection<String> items);
  public List<String> getContainerRuntimeSearchRegistries();
  public String getContainerRuntimeSearchRegistry(int index);
  public String getFirstContainerRuntimeSearchRegistry();
  public String getLastContainerRuntimeSearchRegistry();
  public String getMatchingContainerRuntimeSearchRegistry(Predicate<String> predicate);
  public Boolean hasMatchingContainerRuntimeSearchRegistry(Predicate<String> predicate);
  public A withContainerRuntimeSearchRegistries(List<String> containerRuntimeSearchRegistries);
  public A withContainerRuntimeSearchRegistries(java.lang.String... containerRuntimeSearchRegistries);
  public Boolean hasContainerRuntimeSearchRegistries();
  public A addToInsecureRegistries(int index,String item);
  public A setToInsecureRegistries(int index,String item);
  public A addToInsecureRegistries(java.lang.String... items);
  public A addAllToInsecureRegistries(Collection<String> items);
  public A removeFromInsecureRegistries(java.lang.String... items);
  public A removeAllFromInsecureRegistries(Collection<String> items);
  public List<String> getInsecureRegistries();
  public String getInsecureRegistry(int index);
  public String getFirstInsecureRegistry();
  public String getLastInsecureRegistry();
  public String getMatchingInsecureRegistry(Predicate<String> predicate);
  public Boolean hasMatchingInsecureRegistry(Predicate<String> predicate);
  public A withInsecureRegistries(List<String> insecureRegistries);
  public A withInsecureRegistries(java.lang.String... insecureRegistries);
  public Boolean hasInsecureRegistries();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
